@@ -162,8 +162,8 @@ class SAORMProvider(IProvider):
             except AttributeError:
                 # Relations won't be attributes, but can't be primary anyway.
                 continue
-            if value.primary_key and not value.key in fields:
-                fields.append(value.key)
+            if value.primary_key and not field_name in fields:
+                fields.append(field_name)
         return fields
 
     def get_primary_field(self, entity):
@@ -177,7 +177,7 @@ class SAORMProvider(IProvider):
                 return column.key
         return None
 
-    def get_view_field_name(self, entity, possible_names):
+    def get_view_field_name(self, entity, possible_names, item=None):
         view_field = self._find_title_column(entity)
 
         fields = self.get_fields(entity)
@@ -187,13 +187,13 @@ class SAORMProvider(IProvider):
                     view_field = actual_name
                     break
             if view_field:
-                break;
+                break
             for actual_name in fields:
                 if column_name in actual_name:
                     view_field = actual_name
                     break
             if view_field:
-                break;
+                break
         if view_field is None:
             view_field = fields[0]
         return view_field
